pub struct VassalTask {Show 15 fields
pub id: Uuid,
pub template_task_id: Uuid,
pub suzerain_id: Uuid,
pub suzerain_power: i64,
pub vassal_id: Uuid,
pub vassal_power: i64,
pub good_reward: Vec<CurrencyUnit>,
pub bad_reward: Vec<CurrencyUnit>,
pub good_loyalty: i64,
pub bad_loyalty: i64,
pub task_status: VassalTaskStatus,
pub claimed_by_suzerain: bool,
pub claimed_by_vassal: bool,
pub started_at: Option<DateTime<Utc>>,
pub finish_at: Option<DateTime<Utc>>,
}Expand description
Task in state
Fields
id: Uuidtemplate_task_id: Uuidsuzerain_id: Uuidsuzerain_power: i64vassal_id: Uuidvassal_power: i64good_reward: Vec<CurrencyUnit>bad_reward: Vec<CurrencyUnit>good_loyalty: i64bad_loyalty: i64task_status: VassalTaskStatusclaimed_by_suzerain: boolclaimed_by_vassal: boolstarted_at: Option<DateTime<Utc>>finish_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for VassalTask
impl Clone for VassalTask
Sourcefn clone(&self) -> VassalTask
fn clone(&self) -> VassalTask
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for VassalTask
impl CustomType for VassalTask
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for VassalTask
impl Debug for VassalTask
Sourceimpl<'de> Deserialize<'de> for VassalTask
impl<'de> Deserialize<'de> for VassalTask
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VassalTask
impl JsonSchema for VassalTask
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VassalTask
impl PartialEq for VassalTask
Sourceimpl Serialize for VassalTask
impl Serialize for VassalTask
Sourceimpl Tsify for VassalTask
impl Tsify for VassalTask
const DECL: &'static str = "/**\n * Task in state\n */\nexport interface VassalTask {\n id: Uuid;\n template_task_id: Uuid;\n suzerain_id: Uuid;\n suzerain_power: number;\n vassal_id: Uuid;\n vassal_power: number;\n good_reward: CurrencyUnit[];\n bad_reward: CurrencyUnit[];\n good_loyalty: number;\n bad_loyalty: number;\n task_status: VassalTaskStatus;\n claimed_by_suzerain: boolean;\n claimed_by_vassal: boolean;\n started_at: DateTime<Utc> | null;\n finish_at: DateTime<Utc> | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for VassalTask
impl StructuralPartialEq for VassalTask