pub struct VassalTaskTemplate {
pub id: Uuid,
pub title: I18nString,
pub duration_sec: u64,
pub reward_script: String,
pub loyalty_script: String,
}Expand description
Task in config
Fields
id: Uuidtitle: I18nStringduration_sec: u64reward_script: Stringloyalty_script: StringTrait Implementations
Sourceimpl Clone for VassalTaskTemplate
impl Clone for VassalTaskTemplate
Sourcefn clone(&self) -> VassalTaskTemplate
fn clone(&self) -> VassalTaskTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VassalTaskTemplate
impl Debug for VassalTaskTemplate
Sourceimpl<'de> Deserialize<'de> for VassalTaskTemplate
impl<'de> Deserialize<'de> for VassalTaskTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VassalTaskTemplate
impl JsonSchema for VassalTaskTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for VassalTaskTemplate
impl Serialize for VassalTaskTemplate
Sourceimpl Tsify for VassalTaskTemplate
impl Tsify for VassalTaskTemplate
const DECL: &'static str = "/**\n * Task in config\n */\nexport interface VassalTaskTemplate {\n id: Uuid;\n title: I18nString;\n duration_sec: number;\n reward_script: string;\n loyalty_script: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>